@@ -3,18 +3,14 @@
 #include <sys/time.h>
 #include <string.h>
 #include <math.h>
-
 #define CROSS_SINE(v0, v1) ((v0).x * (v1).y - (v1).x * (v0).y)
 #define LENGTH(v0) (sqrt((v0).x * (v0).x + (v0).y * (v0).y))
-
-
 #ifdef __STDC__
 extern double log2(double);
 #else
 extern double log2();
 #endif
 
-
 node_t qs[QSIZE];		/* Query structure */
 trap_t tr[TRSIZE];		/* Trapezoid structure */
 segment_t seg[SEGSIZE];		/* Segment table */
@@ -307,7 +303,7 @@ static int traverse_polygon(mcur, trnum, from, dir)
   int mnew;
   int v0, v1;
   int retval=0;
-  int do_switch = FALSE;
+  //int do_switch = FALSE;
 
   if ((trnum <= 0) || visited[trnum])
     return 0;
@@ -332,7 +328,7 @@ static int traverse_polygon(mcur, trnum, from, dir)
 	  v1 = t->lseg;
 	  if (from == t->d1)
 	    {
-	      do_switch = TRUE;
+	      //do_switch = TRUE;
 	      mnew = make_new_monotone_poly(mcur, v1, v0);
 	      traverse_polygon(mcur, t->d1, trnum, TR_FROM_UP);
 	      traverse_polygon(mnew, t->d0, trnum, TR_FROM_UP);
@@ -362,7 +358,7 @@ static int traverse_polygon(mcur, trnum, from, dir)
 	  v1 = tr[t->u0].rseg;
 	  if (from == t->u1)
 	    {
-	      do_switch = TRUE;
+	      //do_switch = TRUE;
 	      mnew = make_new_monotone_poly(mcur, v1, v0);
 	      traverse_polygon(mcur, t->u1, trnum, TR_FROM_DN);
 	      traverse_polygon(mnew, t->u0, trnum, TR_FROM_DN);
@@ -394,7 +390,7 @@ static int traverse_polygon(mcur, trnum, from, dir)
 	  if (((dir == TR_FROM_DN) && (t->d1 == from)) ||
 	      ((dir == TR_FROM_UP) && (t->u1 == from)))
 	    {
-	      do_switch = TRUE;
+	      //do_switch = TRUE;
 	      mnew = make_new_monotone_poly(mcur, v1, v0);
 	      traverse_polygon(mcur, t->u1, trnum, TR_FROM_DN);
 	      traverse_polygon(mcur, t->d1, trnum, TR_FROM_UP);
@@ -420,7 +416,7 @@ static int traverse_polygon(mcur, trnum, from, dir)
 	      retval = SP_2UP_LEFT;
 	      if ((dir == TR_FROM_UP) && (t->u0 == from))
 		{
-		  do_switch = TRUE;
+		  //do_switch = TRUE;
 		  mnew = make_new_monotone_poly(mcur, v1, v0);
 		  traverse_polygon(mcur, t->u0, trnum, TR_FROM_DN);
 		  traverse_polygon(mnew, t->d0, trnum, TR_FROM_UP);
@@ -443,7 +439,7 @@ static int traverse_polygon(mcur, trnum, from, dir)
 	      retval = SP_2UP_RIGHT;
 	      if ((dir == TR_FROM_UP) && (t->u1 == from))
 		{
-		  do_switch = TRUE;
+		  //do_switch = TRUE;
 		  mnew = make_new_monotone_poly(mcur, v1, v0);
 		  traverse_polygon(mcur, t->u1, trnum, TR_FROM_DN);
 		  traverse_polygon(mnew, t->d1, trnum, TR_FROM_UP);
@@ -472,7 +468,7 @@ static int traverse_polygon(mcur, trnum, from, dir)
 	      retval = SP_2DN_LEFT;
 	      if (!((dir == TR_FROM_DN) && (t->d0 == from)))
 		{
-		  do_switch = TRUE;
+		  //do_switch = TRUE;
 		  mnew = make_new_monotone_poly(mcur, v1, v0);
 		  traverse_polygon(mcur, t->u1, trnum, TR_FROM_DN);
 		  traverse_polygon(mcur, t->d1, trnum, TR_FROM_UP);
@@ -496,7 +492,7 @@ static int traverse_polygon(mcur, trnum, from, dir)
 	      retval = SP_2DN_RIGHT;
 	      if ((dir == TR_FROM_DN) && (t->d1 == from))
 		{
-		  do_switch = TRUE;
+		  //do_switch = TRUE;
 		  mnew = make_new_monotone_poly(mcur, v1, v0);
 		  traverse_polygon(mcur, t->d1, trnum, TR_FROM_UP);
 		  traverse_polygon(mnew, t->u1, trnum, TR_FROM_DN);
@@ -523,7 +519,7 @@ static int traverse_polygon(mcur, trnum, from, dir)
 	      retval = SP_SIMPLE_LRDN;
 	      if (dir == TR_FROM_UP)
 		{
-		  do_switch = TRUE;
+		  //do_switch = TRUE;
 		  mnew = make_new_monotone_poly(mcur, v1, v0);
 		  traverse_polygon(mcur, t->u0, trnum, TR_FROM_DN);
 		  traverse_polygon(mcur, t->u1, trnum, TR_FROM_DN);
@@ -548,7 +544,7 @@ static int traverse_polygon(mcur, trnum, from, dir)
 	      retval = SP_SIMPLE_LRUP;
 	      if (dir == TR_FROM_UP)
 		{
-		  do_switch = TRUE;
+		  //do_switch = TRUE;
 		  mnew = make_new_monotone_poly(mcur, v1, v0);
 		  traverse_polygon(mcur, t->u0, trnum, TR_FROM_DN);
 		  traverse_polygon(mcur, t->u1, trnum, TR_FROM_DN);
@@ -793,16 +789,15 @@ int testclock(double *x,double *y,int last) {
 		ang2=bacos((x[rang]-x[rang+1])/d);
 	}
 
-	if (ang1>ang2) return 1; //clockwise order
-	else return 0; //anti-clockwise order
+	if (ang1>ang2) return 1; /*clockwise order*/
+	else return 0; /*anti-clockwise order*/
 }
 
 
 /* Generate a random permutation of the segments 1..n */
-int generate_random_ordering(int n)
-{	int lig, i,j, k;
+int generate_random_ordering(int n) {
+	int lig, i,j, k;
 	double z;
-
 	choose_idx = 1;
 	for (i = 1; i <= n; i++)
 		permute[i]=i;
@@ -818,20 +813,16 @@ int generate_random_ordering(int n)
 	return 0;
 }
 
-
 /* Return the next segment in the generated random ordering of all the */
 /* segments in S */
-int choose_segment()
-{
+int choose_segment() {
 #ifdef DEBUG
   Rprintf("choose_segment: %d\n", permute[choose_idx]);
 #endif
   return permute[choose_idx++];
 }
 
-
 #ifdef STANDALONE
-
 /* Read in the list of vertices from infile */
 int read_segments(filename, genus)
      char *filename;
@@ -1367,7 +1358,8 @@ static int add_segment(segnum)
   int tfirstr=0, tlastr=0, tfirstl, tlastl;
   int i1, i2, t, tn;
   point_t tpt;
-  int tritop = 0, tribot = 0, is_swapped = 0;
+  //int tritop = 0;
+  int tribot = 0, is_swapped = 0;
   int tmptriseg,tmpseg=0;
 
   s = seg[segnum];
@@ -1437,7 +1429,7 @@ static int add_segment(segnum)
   else				/* v0 already present */
     {       /* Get the topmost intersecting trapezoid */
       tfirst = locate_endpoint(&s.v0, &s.v1, s.root0);
-      tritop = 1;
+      //tritop = 1;
     }
 
 
@@ -2028,7 +2020,8 @@ int triangulate_polygon(ncontours, cntr, vertices, triangles)
      int **triangles;
 {
   register int i;
-  int nmonpoly, ccount, npoints, genus;
+  int nmonpoly, ccount, npoints;
+  //int genus;
   int n;
 
   memset((void *)seg, 0, sizeof(seg));
@@ -2073,7 +2066,7 @@ int triangulate_polygon(ncontours, cntr, vertices, triangles)
       ccount++;
     }
 
-  genus = ncontours - 1;
+  //genus = ncontours - 1;
   n = i-1;
 
   initialise(n);
